<?php

declare( strict_types=1 );

namespace Blockify;

use DOMElement;
use function explode;
use function implode;
use function str_contains;
use function add_filter;

add_filter( 'render_block', NS . 'render_button_block', 10, 2 );
/**
 * Modifies front end HTML output of block.
 *
 * @since 0.0.2
 *
 * @param string $content
 * @param array  $block
 *
 * @return string
 */
function render_button_block( string $content, array $block ): string {
	if ( 'core/button' !== $block['blockName'] ) {
		return $content;
	}

	if ( str_contains( $content, '-border-' ) ) {
		$dom = dom( $content );

		/**
		 * @var $button DOMElement Fixes button link border inheritance.
		 */
		$button      = $dom->firstChild;
		$classes     = explode( ' ', $button->getAttribute( 'class' ) );
		$styles      = explode( ';', $button->getAttribute( 'style' ) );
		$new_classes = [];
		$new_styles  = [];

		foreach ( $classes as $class ) {
			if ( ! str_contains( $class, '-border-' ) ) {
				$new_classes[] = $class;
			}
		}

		foreach ( $styles as $style ) {
			if ( ! str_contains( $style, 'border-' ) ) {
				$new_styles[] = $style;
			}
		}

		$button->setAttribute( 'class', implode( ' ', $new_classes ) );
		$button->setAttribute( 'style', implode( ';', $new_styles ) );

		if ( ! $button->getAttribute( 'style' ) ) {
			$button->removeAttribute( 'style' );
		}

		$content = $dom->saveHTML();
	}

	return $content;
}
