<?php

declare( strict_types=1 );

namespace Blockify;

use DOMElement;
use function add_filter;
use function is_null;

add_filter( 'render_block', NS . 'render_block_layout', 10, 2 );
/**
 * Modifies front end HTML output of block.
 *
 * @since 0.0.20
 *
 * @param string $content
 * @param array  $block
 *
 * @return string
 */
function render_block_layout( string $content, array $block ): string {
	if ( ! \in_array( $block['blockName'], [ 'core/group' ] ) ) {
		//return $content;
	}

	$block_gap      = $block['attrs']['style']['spacing']['blockGap'] ?? null;
	$content_size   = $block['attrs']['layout']['contentSize'] ?? null;
	$wide_size      = $block['attrs']['layout']['wideSize'] ?? null;
	$inherit_layout = $block['attrs']['layout']['inherit'] ?? null;

	if ( is_null( $block_gap ?? $content_size ?? $wide_size ?? $inherit_layout ) ) {
		return $content;
	}

	$dom = dom( $content );

	/**
	 * @var $first DOMElement
	 */
	$first = $dom->firstChild;

	if ( ! $first ) {
		return $content;
	}

	$style = $first->getAttribute( 'style' );
	$class = $first->getAttribute( 'class' );

	if ( $block_gap ) {
//		$style .= ( $style ? ';' : '' ) . '--wp--style--block-gap:' . $block_gap;
	}

	if ( $inherit_layout ) {
		$class .= ' inherit-layout';
	}

	if ( $content_size ) {
//		$style .= ( $style ? ';' : '' ) . '--wp--custom--layout--content-size:' . $content_size;
	}

	if ( $wide_size ) {
//		$style .= ( $style ? ';' : '' ) . '--wp--custom--layout--content-size:' . $wide_size;
	}

	$first->setAttribute( 'style', $style );
	$first->setAttribute( 'class', $class );

	return $dom->saveHTML();
}
