<?php

declare( strict_types=1 );

namespace Blockify;

add_filter( 'render_block', NS . 'render_template_part_block', 10, 2 );
/**
 * Modifies front end HTML output of block.
 *
 * @since 0.0.2
 *
 * @param string $content
 * @param array  $block
 *
 * @return string
 */
function render_template_part_block( string $content, array $block ): string {
	if ( $block['blockName'] !== 'core/template-part' ) {
		return $content;
	}

	$dom = dom( $content );

	/**
	 * @var $first \DOMElement
	 */
	$first = $dom->firstChild;

	$styles['position'] = $block['attrs']['position'] ?? '';
	$styles['top']      = $block['attrs']['inset']['top'] ?? '';
	$styles['right']    = $block['attrs']['inset']['right'] ?? '';
	$styles['bottom']   = $block['attrs']['inset']['bottom'] ?? '';
	$styles['left']     = $block['attrs']['inset']['left'] ?? '';
	$styles['z-index']  = $block['attrs']['zIndex'] ?? '';

	$css = $first->getAttribute( 'style' );

	foreach ( $styles as $property => $value ) {
		$css .= $value ? "$property:$value;" : '';
	}

	if ( $styles ) {
		$first->setAttribute( 'style', $css );
	}

	$first->setAttribute( 'class', $first->getAttribute( 'class' ) . ( isset( $block['attrs']['position'] ) ? ' position-' . $block['attrs']['position'] : '' ) );

	return $dom->saveHTML();
}
